@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: vector-instances
 version: 3.3.1
-id: vector-instances-3.3.1-58179fcd4f5e524f89d8d30f0f28d3d1
-key: vecto_IqI2Z1FlkEI4wN4cUy4e7q
+id: vector-instances-3.3.1-86a43cd9ce3eb5ed2f259da8231c727e
+key: vecto_79GP7i1Ksos9CDH9oIrUvc
 license: BSD3
 maintainer: ekmett@gmail.com
 homepage: http://github.com/ekmett/vector-instances
@@ -17,14 +17,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-instances-3.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-instances-3.3.1
-hs-libraries: HSvector-instances-3.3.1-IqI2Z1FlkEI4wN4cUy4e7q
+hs-libraries: HSvector-instances-3.3.1-79GP7i1Ksos9CDH9oIrUvc
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-9a3bede31f7f9dbe4efd0f02bc9ca766
-    keys-3.11-e8b0d316d522e372d8b8151d1187a042
-    pointed-5-cd769d29c367a186cee815cfa6956cb1
-    semigroupoids-5.0.1-e4734876ceb621b0eefb491ac209dad3
-    semigroups-0.18.1-34c490e60d2f8a8cae75b79e944c6c08
+    comonad-5-530ea4e1d08a0115920b946124e760ac
+    keys-3.11-2e2d252dcf362b6ae0acb007faf75b9e
+    pointed-5-1c4ea7ecb001f7c0b5b892b982c3648b
+    semigroupoids-5.0.1-fafa53fc1a76ec617ee4419105d11368
+    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock
 haddock-html: /usr/share/doc/haskell-vector-instances/html
